#include <Wire.h>
#include <LiquidCrystal_I2C.h>

#define SENSOR_APIN A3
#define SENSOR_PIN 7
#define BUZZER_PIN 8
#define GREEN_LED 9
#define RED_LED 10

int alarm = 0;
LiquidCrystal_I2C lcd(0x27, 16, 2);

void setup() {
  Serial.begin(9600);

  // Configure the pins as output using the DDRx registers
  DDRB |= (1 << DDB1) | (1 << DDB2); // Set PB1 (pin 9) and PB2 (pin 10) as outputs

  pinMode(BUZZER_PIN, OUTPUT);
  
  lcd.init();
  lcd.backlight();
}

void loop() {
  // put your main code here, to run repeatedly:

  int gas_value = analogRead(SENSOR_APIN);
  Serial.println(gas_value);

  int sensor_value = digitalRead(SENSOR_PIN);
  if (sensor_value == LOW) {
    // Turn on RED_LED (pin 10) and turn off GREEN_LED (pin 9) using the PORTx registers
    PORTB |= (1 << PORTB2);  // Set PB2 (pin 10) HIGH
    PORTB &= ~(1 << PORTB1); // Set PB1 (pin 9) LOW

    if (alarm == 0) {
      tone(BUZZER_PIN, 300);
      alarm = 1;
    } else {
      tone(BUZZER_PIN, 1000);
      alarm = 0;
    }

    lcd.setCursor(1, 0);
    lcd.print("Leak detected!");
    lcd.setCursor(1, 1);
    lcd.print("Value: ");
    lcd.print(gas_value);
    lcd.print(" ppm");
  } else {
    // Turn off RED_LED (pin 10) and turn on GREEN_LED (pin 9) using the PORTx registers
    PORTB &= ~(1 << PORTB2); // Set PB2 (pin 10) LOW
    PORTB |= (1 << PORTB1);  // Set PB1 (pin 9) HIGH

    noTone(BUZZER_PIN);

    lcd.setCursor(1, 0);
    lcd.print("Gas level OK!");
    lcd.setCursor(1, 1);
    lcd.print("Value: ");
    lcd.print(gas_value);
    lcd.print(" ppm");
  }

  delay(500);
  lcd.clear();
}
